from ingenialink.enums.register import RegDtype

DIST_FRAME_SIZE_BYTES = 128
DIST_FRAME_SIZE = 512

DEFAULT_MESSAGE_RETRIES = 7
DEFAULT_MESSAGE_TIMEOUT = 200

DEFAULT_ETH_CONNECTION_TIMEOUT = 1
DEFAULT_PDS_TIMEOUT = 1000

DEFAULT_DRIVE_NAME = "Drive"

MCB_CMD_READ = 1
MCB_CMD_WRITE = 2
MCB_CMD_ACK = 3

PASSWORD_STORE_ALL = 0x65766173
PASSWORD_RESTORE_ALL = 0x64616F6C
PASSWORD_STORE_RESTORE_TCP_IP = 0x636F6D73
PASSWORD_STORE_RESTORE_SUB_0 = 0x73756230
PASSWORD_STORE_SAFETY_REGS = 0x45564153
PASSWORD_RESTORE_SAFETY_REGS = 0x44414F4C

CAN_MONITORING_MAPPED_REGISTERS_START_ADD = 0x58D000

MONITORING_BUFFER_SIZE = 512

data_type_size = {
    RegDtype.U8: 1,
    RegDtype.S8: 1,
    RegDtype.U16: 2,
    RegDtype.S16: 2,
    RegDtype.U32: 4,
    RegDtype.S32: 4,
    RegDtype.U64: 8,
    RegDtype.S64: 8,
    RegDtype.FLOAT: 4,
}

CAN_MAX_WRITE_SIZE = 512
ETH_MAX_WRITE_SIZE = 512
ETH_BUF_SIZE = 1024

CANOPEN_ADDRESS_OFFSET = 0x2000
CANOPEN_SUBNODE_0_ADDRESS_OFFSET = 0x5800
MAP_ADDRESS_OFFSET = 0x800

ECAT_STATE_CHANGE_TIMEOUT_US = 50_000
